@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: edit.php,v 1.9 2006/09/16 13:26:18 gruberroland Exp $
+$Id: edit.php,v 1.11 2008/01/08 18:28:43 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   Copyright (C) 2003 - 2006  Tilo Lutz
@@ -57,8 +57,8 @@ setlanguage();
 
 //load account
 if (isset($_GET['DN'])) {
-	$DN = str_replace("\'", '', $_GET['DN']);
-	$type = str_replace("\'", '', $_GET['type']);
+	$DN = str_replace("\\'", '', $_GET['DN']);
+	$type = str_replace("\\'", '', $_GET['type']);
 	if ($_GET['type'] == $type) $type = str_replace("'", '',$_GET['type']);
 	if ($_GET['DN'] == $DN) $DN = str_replace("'", '',$_GET['DN']);
 	$_SESSION['account'] = new accountContainer($type, 'account');
@@ -78,7 +78,7 @@ if (isset($_GET['DN'])) {
 }
 // new account
 else if (count($_POST)==0) {
-	$type = str_replace("\'", '', $_GET['type']);
+	$type = str_replace("\\'", '', $_GET['type']);
 	if ($_GET['type'] == $type) $type = str_replace("'", '',$_GET['type']);
 	$_SESSION['account'] = new accountContainer($type, 'account');
 	$_SESSION['account']->new_account();
