@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: confmodules.php,v 1.20 2006/11/13 17:43:21 gruberroland Exp $
+$Id: confmodules.php,v 1.24 2008/01/01 13:06:50 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   Copyright (C) 2004 - 2006  Roland Gruber
@@ -75,6 +75,7 @@ echo $_SESSION['header'];
 
 echo "<title>" . _("LDAP Account Manager Configuration") . "</title>\n";
 echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"../../style/layout.css\">\n";
+echo "<link rel=\"shortcut icon\" type=\"image/x-icon\" href=\"../../graphics/favicon.ico\">\n";
 for ($i = 0; $i < sizeof($types); $i++){
 	echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"../../style/type_" . $types[$i] . ".css\">\n";
 }
@@ -171,14 +172,15 @@ function config_showAccountModules($scope, $title) {
 	}
 	
 	// show account modules
-	echo "<fieldset class=\"" . $scope . "edit\"><legend><b>" . $title . "</b></legend>\n";
+	$icon = '<img alt="' . $scope . '" src="../../graphics/' . $scope . '.png">&nbsp;';
+	echo "<fieldset class=\"" . $scope . "edit\"><legend>$icon<b>" . $title . "</b></legend><br>\n";
 	echo "<table border=0 width=\"100%\">\n";
 		// select boxes
 		echo "<tr>\n";
 			echo "<td width=\"5%\"></td>\n";
 			echo "<td width=\"40%\">\n";
 				echo "<fieldset class=\"" . $scope . "edit\">\n";
-					echo "<legend>" . _("Selected modules") . "</legend>\n";
+					echo "<legend>" . _("Selected modules") . "</legend><br>\n";
 					echo "<select class=\"" . $scope . "edit\" name=\"" . $scope . "_selected[]\" size=5 multiple>\n";
 						for ($i = 0; $i < sizeof($selected); $i++) {
 							if (in_array($selected[$i], $available)) {  // selected modules must be available
@@ -206,7 +208,7 @@ function config_showAccountModules($scope, $title) {
 			echo "</td>\n";
 			echo "<td width=\"40%\">\n";
 				echo "<fieldset class=\"" . $scope . "edit\">\n";
-					echo "<legend>" . _("Available modules") . "</legend>\n";
+					echo "<legend>" . _("Available modules") . "</legend><br>\n";
 					echo "<select class=\"" . $scope . "edit\" name=\"" . $scope . "_available[]\" size=5 multiple>\n";
 						for ($i = 0; $i < sizeof($available); $i++) {
 							if (! in_array($available[$i], $selected)) {  // display non-selected modules
@@ -269,7 +271,7 @@ function config_showAccountModules($scope, $title) {
 	
 	echo "</fieldset>\n";
 	
-	echo "<p></p>\n";
+	echo "<br>\n";
 	
 	return ($no_conflicts & $no_depends & $no_missing_basemodule);
 	
