@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: mainmanage.php,v 1.5 2006/09/24 14:19:50 gruberroland Exp $
+$Id: mainmanage.php,v 1.11 2008/04/24 18:45:15 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   Copyright (C) 2003 - 2006  Roland Gruber
@@ -44,7 +44,7 @@ setlanguage();
 $cfg = new LAMCfgMain();
 
 // check if user is logged in
-if (!isset($_SESSION["mainconf_password"]) || ($_SESSION["mainconf_password"] != $cfg->password)) {
+if (!isset($_SESSION["mainconf_password"]) || (!$cfg->checkPassword($_SESSION["mainconf_password"]))) {
 	require('mainlogin.php');
 	exit();
 }
@@ -59,6 +59,7 @@ echo $_SESSION['header'];
 			?>
 		</title>
 		<link rel="stylesheet" type="text/css" href="../../style/layout.css">
+		<link rel="shortcut icon" type="image/x-icon" href="../../graphics/favicon.ico">
 	</head>
 	<body>
 		<p align="center"><a href="http://lam.sourceforge.net" target="_blank">
@@ -69,7 +70,7 @@ echo $_SESSION['header'];
 <?php
 
 // check if submit button was pressed
-if ($_POST['submit']) {
+if (isset($_POST['submit'])) {
 	// remove double slashes if magic quotes are on
 	if (get_magic_quotes_gpc() == 1) {
 		$postKeys = array_keys($_POST);
@@ -81,7 +82,7 @@ if ($_POST['submit']) {
 	// set master password
 	if (isset($_POST['masterpassword']) && ($_POST['masterpassword'] != "")) {
 		if ($_POST['masterpassword'] && $_POST['masterpassword2'] && ($_POST['masterpassword'] == $_POST['masterpassword2'])) {
-			$cfg->password = $_POST['masterpassword'];
+			$cfg->setPassword($_POST['masterpassword']);
 			$msg = _("New master password set successfully.");
 			unset($_SESSION["mainconf_password"]);
 		}
@@ -116,11 +117,18 @@ if ($_POST['submit']) {
 	if ($_POST['logDestination'] == "none") $cfg->logDestination = "NONE";
 	elseif ($_POST['logDestination'] == "syslog") $cfg->logDestination = "SYSLOG";
 	else {
-		if (isset($_POST['logFile']) && ($_POST['logFile'] != "") && eregi("^[a-z0-9/\\\:\\._-]+$", $_POST['logFile'])) {
+		if (isset($_POST['logFile']) && ($_POST['logFile'] != "") && eregi("^[a-z0-9/\\\\:\\._-]+$", $_POST['logFile'])) {
 			$cfg->logDestination = $_POST['logFile'];
 		}
 		else $errors[] = _("The log file is empty or contains invalid characters! Valid characters are: a-z, A-Z, 0-9, /, \\, ., :, _ and -.");
 	}
+	// password policies
+	$cfg->passwordMinLength = $_POST['passwordMinLength'];
+	$cfg->passwordMinLower = $_POST['passwordMinLower'];
+	$cfg->passwordMinUpper = $_POST['passwordMinUpper'];
+	$cfg->passwordMinNumeric = $_POST['passwordMinNumeric'];
+	$cfg->passwordMinSymbol = $_POST['passwordMinSymbol'];
+	$cfg->passwordMinClasses = $_POST['passwordMinClasses'];
 	// save settings
 	$cfg->save();
 	// print messages
@@ -143,7 +151,7 @@ if ($_POST['submit']) {
 		<tr><td>
 		<fieldset>
 			<legend><b> <?php echo _("Security settings"); ?> </b></legend>
-			<p>
+			<br>
 			<table cellspacing="0" border="0">
 				<!-- session timeout -->
 				<tr>
@@ -194,9 +202,50 @@ if ($_POST['submit']) {
 			</table>
 		</fieldset>
 		<BR>
+		<fieldset>
+			<legend><b> <?php echo _("Password policy"); ?> </b></legend>
+			<br>
+			<table cellspacing="0" border="0">
+			<?php
+				$options = array(
+					array('passwordMinLength', _('Minimum password length'), 20),
+					array('passwordMinLower', _('Minimum lowercase characters'), 20),
+					array('passwordMinUpper', _('Minimum uppercase characters'), 20),
+					array('passwordMinNumeric', _('Minimum numeric characters'), 20),
+					array('passwordMinSymbol', _('Minimum symbolic characters'), 20),
+					array('passwordMinClasses', _('Minimum character classes'), 4)
+				);
+				for ($i = 0; $i < sizeof($options); $i++) {
+					echo "<tr>\n";
+						echo "<td>\n";
+							echo $options[$i][1] . "&nbsp;&nbsp;";
+						echo "</td>\n";
+						echo "<td>\n";
+							echo "<select name=\"" . $options[$i][0] . "\">\n";
+								for ($o = 0; $o <= $options[$i][2]; $o++) {
+									$selected = '';
+									if ($cfg->$options[$i][0] == $o) {
+										$selected = ' selected';
+									}
+									echo "<option" . $selected . ">" . $o . "</option>\n";
+								}
+							echo "</select>\n";
+						echo "</td>\n";
+						echo "<td>\n";
+							echo "<a href=\"../help.php?HelpNumber=242\" target=\"lamhelp\">";
+							echo "<img src=\"../../graphics/help.png\" alt=\"" . _('Help') . "\" title=\"" . _('Help') . "\">";
+							echo "</a>\n";
+						echo "</td>\n";
+					echo "</tr>\n";
+				}
+			?>
+			</table>
+			<br>
+		</fieldset>
+		<BR>
 		<fieldset>
 			<legend><b> <?php echo _("Logging"); ?> </b></legend>
-			<p>
+			<br>
 			<table cellspacing="0" border="0">
 				<!-- log level -->
 				<tr>
@@ -287,7 +336,7 @@ if ($_POST['submit']) {
 		<BR>
 		<fieldset>
 			<legend><b> <?php echo _("Change master password"); ?> </b></legend>
-			<p>
+			<br>
 			<table cellspacing="0" border="0">
 				<!-- set master password -->
 				<tr>
