@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: profmanage.php,v 1.23 2006/09/24 14:19:50 gruberroland Exp $
+$Id: profmanage.php,v 1.27 2008/01/01 13:06:50 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   Copyright (C) 2003 - 2006  Roland Gruber
@@ -51,6 +51,7 @@ echo $_SESSION['header'];
 			?>
 		</title>
 		<link rel="stylesheet" type="text/css" href="../../style/layout.css">
+		<link rel="shortcut icon" type="image/x-icon" href="../../graphics/favicon.ico">
 	</head>
 	<body>
 		<p align="center"><a href="http://lam.sourceforge.net" target="_blank">
@@ -64,7 +65,7 @@ $cfg = new LAMCfgMain();
 // check if submit button was pressed
 if ($_POST['submit']) {
 	// check master password
-	if ($cfg->password != $_POST['passwd']) {
+	if (!$cfg->checkPassword($_POST['passwd'])) {
 		$error = _("Master password is wrong!");
 	}
 	// add new profile
@@ -79,7 +80,7 @@ if ($_POST['submit']) {
 				if ($file) {
 					// load as config and write new password
 					$conf = new LAMConfig($_POST['addprofile']);
-					$conf->Passwd = $_POST['addpassword'];
+					$conf->set_Passwd($_POST['addpassword']);
 					$conf->save();
 					$msg = _("Created new profile.");
 				}
@@ -134,7 +135,7 @@ if ($_POST['submit']) {
 
 
 // check if config.cfg is valid
-if (!isset($cfg->default) && !isset($cfg->password)) {
+if (!isset($cfg->default)) {
 	StatusMessage("ERROR", _("Please set up your master configuration file (config/config.cfg) first!"), "");
 	echo "</body>\n</html>\n";
 	die();
@@ -149,7 +150,7 @@ if (!isset($cfg->default) && !isset($cfg->password)) {
 		<tr><td>
 		<fieldset>
 			<legend><b> <?php echo _("Profile management"); ?> </b></legend>
-			<p>
+			<br>
 			<table cellspacing=0 border=0>
 
 				<!-- add profile -->
@@ -195,7 +196,7 @@ if (!isset($cfg->default) && !isset($cfg->password)) {
 				</tr>
 
 				<tr>
-					<td colspan=4>&nbsp</td>
+					<td colspan=4>&nbsp;</td>
 				</tr>
 
 				<!-- rename profile -->
@@ -229,7 +230,7 @@ if (!isset($cfg->default) && !isset($cfg->password)) {
 				</tr>
 
 				<tr>
-					<td colspan=4>&nbsp</td>
+					<td colspan=4>&nbsp;</td>
 				</tr>
 
 				<!-- delete profile -->
@@ -259,7 +260,7 @@ if (!isset($cfg->default) && !isset($cfg->password)) {
 				</tr>
 
 				<tr>
-					<td colspan=4>&nbsp</td>
+					<td colspan=4>&nbsp;</td>
 				</tr>
 
 				<!-- set profile password -->
@@ -302,7 +303,7 @@ if (!isset($cfg->default) && !isset($cfg->password)) {
 				</tr>
 
 				<tr>
-					<td colspan=4>&nbsp</td>
+					<td colspan=4>&nbsp;</td>
 				</tr>
 
 				<!-- change default profile -->
@@ -341,17 +342,17 @@ if (!isset($cfg->default) && !isset($cfg->password)) {
 			</fieldset>
 			</td></tr>
 			</table>
-			<p>&nbsp</p>
+			<p>&nbsp;</p>
 
 			<!-- password field and submit button -->
 			<b>
 				<?php echo _("Master password"); ?>:
 			</b>
-			&nbsp
+			&nbsp;
 			<input type="password" name="passwd">
-			&nbsp
+			&nbsp;
 			<input type="submit" name="submit" value=" <?php echo _("Ok"); ?> ">
-			&nbsp
+			&nbsp;
 			<?PHP
 				// help link
 				echo "<a href=\"../help.php?HelpNumber=236\" target=\"lamhelp\">";
