@@ -1,10 +1,10 @@
 <?php
 /*
-	$Id: delete.php,v 1.63 2007/10/26 14:09:20 gruberroland Exp $
+	$Id: delete.php,v 1.67 2008/02/05 18:27:25 gruberroland Exp $
 
 	This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
 	Copyright (C) 2003 - 2006  Tilo Lutz
-	Copyright (C) 2007  Roland Gruber
+	Copyright (C) 2007 - 2008  Roland Gruber
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -49,6 +49,10 @@ include_once('../lib/modules.inc');
 // Start session
 startSecureSession();
 
+if (!checkIfWriteAccessIsAllowed()) {
+	die();
+}
+
 // Redirect to startpage if user is not loged in
 if (!isset($_SESSION['loggedIn'])) {
 	metaRefresh("login.php");
@@ -75,11 +79,12 @@ if (isset($_GET['type']) && isset($_SESSION['delete_dn'])) {
 	echo $_SESSION['header'];
 	echo "<title>LDAP Account Manager</title>\n";
 	echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"../style/layout.css\">\n";
+	echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"../style/type_" . $_GET['type'] . ".css\">\n";
 	echo "</head><body>\n";
 	echo "<form action=\"delete.php\" method=\"post\">\n";
 	echo "<fieldset class=\"".$_GET['type']."edit\"><legend><b>";
 	echo _('Please confirm:');
-	echo "</b></legend>\n";
+	echo "</b></legend><br>\n";
 	echo "<input name=\"type\" type=\"hidden\" value=\"" . $_GET['type'] . "\">\n";
 	echo "<b>" . _("Do you really want to remove the following accounts?") . "</b>";
 	echo "<br><br>\n";
@@ -104,7 +109,7 @@ if (isset($_GET['type']) && isset($_SESSION['delete_dn'])) {
 	$tabindexLink = 1000;
 	foreach ($modules as $module) {
 		$module = new $module($_GET['type']);
-		parseHtml(get_class($module), $module->display_html_delete($_POST), $values, true, $tabindex, $tabindexLink, $_GET['type']);
+		parseHtml(get_class($module), $module->display_html_delete(), $values, true, $tabindex, $tabindexLink, $_GET['type']);
 	}
 	echo "</table>\n";
 	echo "<br>\n";
@@ -126,12 +131,13 @@ if ($_POST['delete']) {
 	echo $_SESSION['header'];
 	echo "<title>LDAP Account Manager</title>\n";
 	echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"../style/layout.css\">\n";
+	echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"../style/type_" . $_POST['type'] . ".css\">\n";
 	echo "</head><body>\n";
 	echo "<form action=\"delete.php\" method=\"post\">\n";
 	echo "<input name=\"type\" type=\"hidden\" value=\"" . $_POST['type'] . "\">\n";
 	echo "<fieldset class=\"".$_POST['type']."edit\"><legend><b>";
 	echo _('Deleting. Please stand by ...');
-	echo "</b></legend>\n";
+	echo "</b></legend><br>\n";
 
 	// Delete dns
 	for ($m=0; $m<count($_SESSION['delete_dn']); $m++) {
