@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: initsuff.php,v 1.16 2007/07/08 10:49:06 gruberroland Exp $
+$Id: initsuff.php,v 1.17 2007/12/30 16:08:54 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   Copyright (C) 2003 - 2006  Roland Gruber
@@ -40,6 +40,10 @@ include_once("../lib/status.inc");
 // start session
 startSecureSession();
 
+if (!checkIfWriteAccessIsAllowed()) {
+	die();
+}
+
 setlanguage();
 
 // check if user already pressed button
