@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: userlink.php,v 1.17 2006/03/26 17:51:25 gruberroland Exp $
+$Id: userlink.php,v 1.18 2007/07/08 10:51:01 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   Copyright (C) 2003 - 2006  Roland Gruber
@@ -77,9 +77,9 @@ else {
 function search_username($name) {
 	$filter = "(uid=$name)";
 	$attrs = array();
-	$sr = @ldap_search($_SESSION['ldap']->server, $_SESSION['config']->get_Suffix('user'), $filter, $attrs);
+	$sr = @ldap_search($_SESSION['ldap']->server(), $_SESSION['config']->get_Suffix('user'), $filter, $attrs);
 	if ($sr) {
-		$info = ldap_get_entries($_SESSION['ldap']->server, $sr);
+		$info = ldap_get_entries($_SESSION['ldap']->server(), $sr);
 		// return only first DN entry
 		$ret = $info[0]["dn"];
 		ldap_free_result($sr);
