@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: login.php,v 1.104 2007/11/03 11:20:52 gruberroland Exp $
+$Id: login.php,v 1.109 2008/03/23 10:57:33 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   Copyright (C) 2003 - 2006  Michael Duergner
@@ -30,6 +30,24 @@ $Id: login.php,v 1.104 2007/11/03 11:20:52 gruberroland Exp $
 
 /** status messages */
 include_once("../lib/status.inc");
+
+// check if PHP >= 5.1
+if (version_compare(phpversion(), '5.1.0') < 0) {
+	echo "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">\n\n";
+	echo "<html>\n<head>\n";
+	echo "<meta http-equiv=\"content-type\" content=\"text/html; charset=UTF-8\">\n";
+	echo "<meta http-equiv=\"pragma\" content=\"no-cache\">\n		<meta http-equiv=\"cache-control\" content=\"no-cache\">\n";
+	echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"../style/layout.css\">\n";
+	echo "<link rel=\"shortcut icon\" type=\"image/x-icon\" href=\"../graphics/favicon.ico\">\n";
+	echo "<title>LDAP Account Manager</title>\n";
+	echo "</head><body>\n";
+	StatusMessage("ERROR", "LAM needs PHP 5 greater or equal as 5.1.0!", "Please upgrade your PHP installation.");
+	echo "<br><br>";
+	echo "</body></html>";
+	exit();
+}
+
+
 /** security functions */
 include_once("../lib/security.inc");
 /** self service functions */
@@ -53,10 +71,6 @@ if (! function_exists('gettext') || !function_exists('_')) {
 if (! function_exists('utf8_decode')) {
 	$criticalErrors[] = array("ERROR", "Your PHP has no XML support!", "Please install the XML extension for PHP.");
 }
-// check if PHP >= 5.1
-if (version_compare(phpversion(), '5.1.0') < 0) {
-	$criticalErrors[] = array("ERROR", "LAM needs PHP 5 greater or equal as 5.1.0!", "Please upgrade your PHP installation.");
-}
 // check file permissions
 $writableDirs = array('sess', 'tmp');
 for ($i = 0; $i < sizeof($writableDirs); $i++) {
@@ -78,12 +92,12 @@ if (isset($memLimit) && ($memLimit != '') && (substr(strtoupper($memLimit), strl
 }
 // stop login if critical errors occured
 if (sizeof($criticalErrors) > 0) {
-	echo "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n";
 	echo "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">\n\n";
 	echo "<html>\n<head>\n";
 	echo "<meta http-equiv=\"content-type\" content=\"text/html; charset=UTF-8\">\n";
 	echo "<meta http-equiv=\"pragma\" content=\"no-cache\">\n		<meta http-equiv=\"cache-control\" content=\"no-cache\">\n";
-	echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"../style/layout.css\">";
+	echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"../style/layout.css\">\n";
+	echo "<link rel=\"shortcut icon\" type=\"image/x-icon\" href=\"../graphics/favicon.ico\">\n";
 	echo "<title>LDAP Account Manager</title>\n";
 	echo "</head><body>\n";
 	for ($i = 0; $i < sizeof($criticalErrors); $i++) {
@@ -129,8 +143,7 @@ function display_LoginPage($config_object) {
 	$_SESSION['language'] = $config_object->get_defaultLanguage();
 
 	$current_language = explode(":",$_SESSION['language']);
-	$_SESSION['header'] = "<?xml version=\"1.0\" encoding=\"" . $current_language[1] . "\"?>\n";
-	$_SESSION['header'] .= "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">\n\n";
+	$_SESSION['header'] = "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">\n\n";
 	$_SESSION['header'] .= "<html>\n<head>\n";
 	$_SESSION['header'] .= "<meta http-equiv=\"content-type\" content=\"text/html; charset=" . $current_language[1] . "\">\n";
 	$_SESSION['header'] .= "<meta http-equiv=\"pragma\" content=\"no-cache\">\n		<meta http-equiv=\"cache-control\" content=\"no-cache\">";
@@ -169,6 +182,7 @@ function display_LoginPage($config_object) {
 	?>
 		<title>LDAP Account Manager -Login-</title>
 		<link rel="stylesheet" type="text/css" href="../style/layout.css">
+		<link rel="shortcut icon" type="image/x-icon" href="../graphics/favicon.ico">
 	</head>
 	<body>
 	<?php
@@ -225,7 +239,7 @@ function display_LoginPage($config_object) {
 						<table width="580">
 							<tr>
 								<td style="border-style:none" height="70" colspan="2" align="center">
-									<font color="darkblue"><b><big><?php echo _("Please select your user name and enter your password to log in."); ?></big></b></font>
+									<font color="#000080"><b><big><?php echo _("Please select your user name and enter your password to log in."); ?></big></b></font>
 								</td>
 							</tr>
 							<tr>
@@ -323,7 +337,7 @@ function display_LoginPage($config_object) {
 								<?php
 								echo _("Server profile") . ": ";
 								if(empty($_POST['profileChange'])) {
-									$_POST['profile'] = $_SESSION['config']->file;
+									$_POST['profile'] = $_SESSION['config']->getName();
 								}
 								?></b>
 								<?php echo $_POST['profile']; ?>
@@ -396,8 +410,7 @@ if(!empty($_POST['checklogin']))
 			$_SESSION['loggedIn'] = true;
 			$_SESSION['language'] = $_POST['language']; // Write selected language in session
 			$current_language = explode(":",$_SESSION['language']);
-			$_SESSION['header'] = "<?xml version=\"1.0\" encoding=\"" . $current_language[1] . "\"?>\n";
-			$_SESSION['header'] .= "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">\n\n";
+			$_SESSION['header'] = "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">\n\n";
 			$_SESSION['header'] .= "<html>\n<head>\n";
 			$_SESSION['header'] .= "<meta http-equiv=\"content-type\" content=\"text/html; charset=" . $current_language[1] . "\">\n";
 			$_SESSION['header'] .= "<meta http-equiv=\"pragma\" content=\"no-cache\">\n		<meta http-equiv=\"cache-control\" content=\"no-cache\">";
