@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: main.php,v 1.36 2007/07/08 10:49:06 gruberroland Exp $
+$Id: main.php,v 1.39 2008/03/23 10:57:33 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   Copyright (C) 2003 - 2006  Roland Gruber
@@ -58,7 +58,6 @@ for ($i = 0; $i < sizeof($types); $i++) {
 $lang = explode(":",$_SESSION['language']);
 $lang = $lang[1];
 
-echo "<?xml version=\"1.0\" encoding=\"$lang\"?>\n";
 echo "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Frameset//EN\" \"http://www.w3.org/TR/html4/frameset.dtd\">\n";
 echo "<html>\n";
 echo "<head>\n";
@@ -67,12 +66,14 @@ echo "<meta http-equiv=\"pragma\" content=\"no-cache\">\n";
 echo "<meta http-equiv=\"cache-control\" content=\"no-cache\">\n";
 echo ("<title>LDAP Account Manager</title>\n");
 echo ("<link rel=\"stylesheet\" type=\"text/css\" href=\"../style/layout.css\">");
+echo "<link rel=\"shortcut icon\" type=\"image/x-icon\" href=\"../graphics/favicon.ico\">\n";
 echo ("</head>\n");
 echo ("<frameset rows=\"150,*\">\n");
 echo ("<frame src=\"./main_header.php\" name=\"head\" frameborder=\"0\">\n");
 // display page to add suffixes, if needed
-if (sizeof($new_suffs) > 0) echo ("<frame src=\"initsuff.php?suffs='" . implode(";", $new_suffs) .
-	"'\" name=\"mainpart\" frameborder=\"0\">\n");
+if ((sizeof($new_suffs) > 0) && checkIfWriteAccessIsAllowed()) {
+	echo ("<frame src=\"initsuff.php?suffs='" . implode(";", $new_suffs) . "'\" name=\"mainpart\" frameborder=\"0\">\n");
+}
 else {
 	if (sizeof($types) > 0) {
 		echo ("<frame src=\"./lists/list.php?type=" . $types[0] . "\" name=\"mainpart\" frameborder=\"0\" scrolling=\"yes\">\n");
