@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: massBuildAccounts.php,v 1.11 2006/03/26 17:51:25 gruberroland Exp $
+$Id: massBuildAccounts.php,v 1.12 2007/12/30 13:15:39 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   Copyright (C) 2004 - 2006  Roland Gruber
@@ -41,6 +41,9 @@ include_once('../lib/modules.inc');
 // Start session
 startSecureSession();
 
+// die if no write access
+if (!checkIfWriteAccessIsAllowed()) die();
+
 // Redirect to startpage if user is not loged in
 if (!isset($_SESSION['loggedIn'])) {
 	metaRefresh("login.php");
