@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: masscreate.php,v 1.71 2007/06/10 14:47:43 gruberroland Exp $
+$Id: masscreate.php,v 1.77 2008/01/08 18:26:13 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   Copyright (C) 2004 - 2006  Roland Gruber
@@ -41,6 +41,9 @@ include_once('../lib/modules.inc');
 // Start session
 startSecureSession();
 
+// die if no write access
+if (!checkIfWriteAccessIsAllowed()) die();
+
 // Redirect to startpage if user is not loged in
 if (!isset($_SESSION['loggedIn'])) {
 	metaRefresh("login.php");
@@ -144,7 +147,7 @@ function showMainPage($scope) {
 	echo "<p><big><b>" . _("Columns:") . "</b></big></p>\n";
 
 	// DN options
-	echo "<fieldset class=\"" . $scope . "edit\">\n<legend><b>" . _("DN settings") . "</b></legend>\n";
+	echo "<fieldset class=\"" . $scope . "edit\">\n<legend><b>" . _("DN settings") . "</b></legend><br>\n";
 	echo "<table width=\"100%\">\n";
 		echo "<tr valign=\"top\">\n";
 			echo "<td width=\"50%\">\n";
@@ -174,7 +177,7 @@ function showMainPage($scope) {
 			echo "</td>\n";
 		echo "</tr>\n";
 	echo "</table>\n";
-	echo "</fieldset>\n";
+	echo "</fieldset><br>\n";
 	
 	// get input fields from modules
 	$columns = getUploadColumns($scope);
@@ -183,7 +186,13 @@ function showMainPage($scope) {
 	$modules = array_keys($columns);
 	for ($m = 0; $m < sizeof($modules); $m++) {
 		if (sizeof($columns[$modules[$m]]) < 1) continue;
-		echo "<fieldset class=\"" . $scope . "edit\">\n<legend><b>" . getModuleAlias($modules[$m], $scope) . "</b></legend>\n";
+		$icon = '';
+		$module = new $modules[$m]($scope);
+		$iconImage = $module->getIcon();
+		if ($iconImage != null) {
+			$icon = '<img align="middle" src="../graphics/' . $iconImage . '" alt="' . $iconImage . '"> ';
+		}
+		echo "<fieldset class=\"" . $scope . "edit\">\n<legend>$icon<b>" . getModuleAlias($modules[$m], $scope) . "</b></legend><br>\n";
 		echo "<table width=\"100%\">\n";
 		for ($i = 0; $i < sizeof($columns[$modules[$m]]); $i++) {
 			echo "<tr valign=\"top\">\n";
@@ -207,13 +216,12 @@ function showMainPage($scope) {
 			echo "</tr>\n";
 		}
 		echo "</table>\n";
-		echo "</fieldset>";
+		echo "</fieldset><br>";
 	}
 
 	echo "<p>&nbsp;</p>\n";
 
 	// print table example and build sample CSV
-	$sampleCSV = "";
 	$sampleCSV_head = array();
 	$sampleCSV_row = array();
 	echo "<big><b>" . _("This is an example how it would look in your spreadsheet program before you convert to CSV:") . "</b></big><br><br>\n";
@@ -271,7 +279,6 @@ function showMainPage($scope) {
 	echo "<br><br>\n";
 	echo "<a href=\"masscreate.php?getCSV=1\"><b>" . _("Download sample CSV file") . "</b></a>\n";
 	echo "<br><br>\n";
-	echo "<p>\n";
 
 	echo "</body>\n";
 	echo "</html>\n";
