@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: ou_edit.php,v 1.20 2007/04/29 20:10:12 gruberroland Exp $
+$Id: ou_edit.php,v 1.22 2007/12/31 12:25:13 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   Copyright (C) 2003 - 2006  Roland Gruber
@@ -40,6 +40,9 @@ include_once("../lib/status.inc");
 // start session
 startSecureSession();
 
+// die if no write access
+if (!checkIfWriteAccessIsAllowed()) die();
+
 setlanguage();
 
 $types = $_SESSION['config']->get_ActiveTypes();
@@ -157,7 +160,7 @@ function display_main() {
 	for ($i = 0; $i < sizeof($types); $i++) {
 		// generate lists of possible suffixes
 		$units = $_SESSION['ldap']->search_units($_SESSION["config"]->get_Suffix($types[$i]));
-		echo ("<fieldset class=\"" . $types[$i] . "edit\"><legend><b>" . getTypeAlias($types[$i]) . "</b></legend>\n");
+		echo ("<fieldset class=\"" . $types[$i] . "edit\"><legend><b>" . getTypeAlias($types[$i]) . "</b></legend><br>\n");
 		echo ("<table border=0>\n");
 		// new OU
 		echo ("<tr>\n");
