@@ -1,9 +1,10 @@
 <?php
 /*
-$Id: pdfdelete.php,v 1.8 2006/03/26 17:51:25 gruberroland Exp $
+$Id: pdfdelete.php,v 1.10 2007/12/30 13:15:39 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
-  Copyright (C) 2004 - 2006  Michael Drgner
+  Copyright (C) 2004 - 2006  Michael Duergner
+  Copyright (C) 2007         Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -25,7 +26,7 @@ $Id: pdfdelete.php,v 1.8 2006/03/26 17:51:25 gruberroland Exp $
 * Manages deletion of pdf structures.
 *
 * @package PDF
-* @author Michael Drgner
+* @author Michael Duergner
 */
 
 /** security functions */
@@ -36,6 +37,9 @@ include_once('../../lib/pdfstruct.inc');
 // start session
 startSecureSession();
 
+// die if no write access
+if (!checkIfWriteAccessIsAllowed()) die();
+
 setlanguage();
 
 // check if user is logged in, if not go to login
@@ -48,6 +52,7 @@ if (!$_SESSION['ldap'] || !$_SESSION['ldap']->server()) {
 echo $_SESSION['header'];
 echo ("<title>" . _("Delete PDF structure") . "</title>\n");
 echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"../../style/layout.css\">\n";
+echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"../../style/type_" . $_POST['type'] . ".css\">\n";
 echo ("</head>\n<body>\n<p><br></p>\n");
 
 // check if admin has submited delete operation
