@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: profilemain.php,v 1.27 2006/03/26 17:51:25 gruberroland Exp $
+$Id: profilemain.php,v 1.29 2007/12/31 13:13:37 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   Copyright (C) 2003 - 2006  Roland Gruber
@@ -40,6 +40,9 @@ include_once("../../lib/config.inc");
 // start session
 startSecureSession();
 
+// die if no write access
+if (!checkIfWriteAccessIsAllowed()) die();
+
 setlanguage();
 
 $types = $_SESSION['config']->get_ActiveTypes();
@@ -108,7 +111,7 @@ for ($i = 0; $i < sizeof($profileClasses); $i++) {
 echo "</head>\n";
 echo "<body>\n";
 
-echo "<p></p>\n";
+echo "<br>\n";
 
 echo "<form action=\"profilemain.php\" method=\"post\">\n";
 
@@ -156,7 +159,7 @@ for ($i = 0; $i < sizeof($profileClasses); $i++) {
 	echo "</table>\n";
 	echo "</fieldset>\n";
 	
-	echo "<p></p>\n";
+	echo "<br>\n";
 	
 }
 
