@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: profilepage.php,v 1.30 2006/03/26 17:51:25 gruberroland Exp $
+$Id: profilepage.php,v 1.34 2007/12/30 13:15:39 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   Copyright (C) 2003 - 2006  Roland Gruber
@@ -44,6 +44,9 @@ include_once("../../lib/status.inc");
 // start session
 startSecureSession();
 
+// die if no write access
+if (!checkIfWriteAccessIsAllowed()) die();
+
 setlanguage();
 
 // check if user is logged in, if not go to login
@@ -65,8 +68,8 @@ if (isset($_POST['abort'])) {
 
 // print header
 echo $_SESSION['header'];
-echo "<title></title>\n<link rel=\"stylesheet\" type=\"text/css\" href=\"../../style/layout.css\">\n";
-echo "<title></title>\n<link rel=\"stylesheet\" type=\"text/css\" href=\"../../style/type_" . $_GET['type'] . ".css\">\n";
+echo "<title>Profile editor</title>\n<link rel=\"stylesheet\" type=\"text/css\" href=\"../../style/layout.css\">\n";
+echo "\n<link rel=\"stylesheet\" type=\"text/css\" href=\"../../style/type_" . $_GET['type'] . ".css\">\n";
 echo "</head><body><br>\n";
 
 // save button was presed
@@ -230,7 +233,13 @@ for ($m = 0; $m < sizeof($modules); $m++) {
 	// ignore modules without options
 	if (sizeof($options[$modules[$m]]) < 1) continue;
 	echo "<fieldset class=\"" . $type . "edit\">\n";
-		echo "<legend><b>" . getModuleAlias($modules[$m], $type) . "</b></legend>\n";
+	$icon = '';
+	$module = new $modules[$m]($type);
+	$iconImage = $module->getIcon();
+	if ($iconImage != null) {
+		$icon = '<img align="middle" src="../../graphics/' . $iconImage . '" alt="' . $iconImage . '"> ';
+	}
+	echo "<legend>$icon<b>" . getModuleAlias($modules[$m], $type) . "</b></legend>\n";
 	$profileTypes = parseHtml($modules[$m], $options[$modules[$m]], $old_options, true, $tabindex, $tabindexLink, $type);
 	$_SESSION['profile_types'] = array_merge($profileTypes, $_SESSION['profile_types']);
 	echo "</fieldset>\n";
