@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: lamdaemonTest.php,v 1.6 2007/06/07 14:27:11 gruberroland Exp $
+$Id: lamdaemonTest.php,v 1.11 2008/01/27 16:12:06 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   Copyright (C) 2006 - 2007  Roland Gruber
@@ -37,6 +37,9 @@ include_once("../../lib/config.inc");
 // start session
 startSecureSession();
 
+// die if no write access
+if (!checkIfWriteAccessIsAllowed()) die();
+
 setlanguage();
 
 echo $_SESSION['header'];
@@ -51,6 +54,71 @@ echo "<body>\n";
 
 echo "<h1 align=\"center\">" . _("Lamdaemon test") . "</h1>\n";
 
+$servers = explode(";", $_SESSION['config']->get_scriptServers());
+$serverIDs = array();
+$serverTitles = array();
+for ($i = 0; $i < sizeof($servers); $i++) {
+	$serverParts = explode(":", $servers[$i]);
+	$serverName = $serverParts[0];
+	$title = $serverName;
+	if (isset($serverParts[1])) {
+		$title = $serverParts[1] . " (" . $serverName . ")";
+	}
+	$serverIDs[] = $serverName;
+	$serverTitles[$serverName] = $title;
+}
+
+if (isset($_POST['runTest'])) {
+	lamRunLamdaemonTestSuite($_POST['server'], $serverTitles[$_POST['server']] , isset($_POST['checkQuotas']));
+}
+else if ((sizeof($servers) > 0) && isset($servers[0]) && ($servers[0] != '')) {
+	echo "<form action=\"lamdaemonTest.php\" method=\"post\">\n";
+	echo "<fieldset class=\"useredit\"><legend><b>" . _("Lamdaemon test") . "</b></legend><br>\n";
+	echo "<table>\n";
+	echo "<tr>\n";
+		echo "<td>\n";
+			echo _("Server");
+		echo "</td>\n";
+		echo "<td>\n";
+			echo "<select name=\"server\">\n";
+				for ($i = 0; $i < sizeof($servers); $i++) {
+					$servers[$i] = explode(":", $servers[$i]);
+					$serverName = $servers[$i][0];
+					$title = $serverName;
+					if (isset($servers[$i][1])) {
+						$title = $servers[$i][1] . " (" . $serverName . ")";
+					}
+					echo "<option value=\"$serverName\">$title</option>\n";
+				}
+			echo "</select>\n";
+		echo "</td>\n";
+	echo "</tr>\n";
+	echo "<tr>\n";
+		echo "<td>\n";
+			echo _("Check quotas");
+		echo "</td>\n";
+		echo "<td>\n";
+			echo "<input type=\"checkbox\" name=\"checkQuotas\">\n";
+		echo "</td>\n";
+	echo "</tr>\n";
+	echo "</table>\n";
+	
+	echo "<br>";
+	
+	echo "<input type=\"submit\" name=\"runTest\" value=\"" . _("Ok") . "\">\n";
+	echo "</fieldset>\n";
+	echo "</form>\n";
+}
+else {
+	StatusMessage("ERROR", _('No lamdaemon server set, please update your LAM configuration settings.'));
+}
+
+
+echo "</body>\n";
+echo "</html>\n";
+
+
+
 /**
  * Runs a test case of lamdaemon.
  *
@@ -61,13 +129,14 @@ echo "<h1 align=\"center\">" . _("Lamdaemon test") . "</h1>\n";
  * @return boolean true, if errors occured
  */
 function lamTestLamdaemon($command, $stopTest, $handle, $testText) {
+	$okImage = "<img src=\"../../graphics/pass.png\" alt=\"\">\n";
+	$failImage = "<img src=\"../../graphics/fail.png\" alt=\"\">\n";
 	// run lamdaemon and get user quotas
 	if (!$stopTest) {
-		echo "<tr class=\"userlist\">\n<td>" . $testText . "&nbsp;&nbsp;</td>\n";
+		echo "<tr class=\"userlist\">\n<td nowrap>" . $testText . "&nbsp;&nbsp;</td>\n";
 		flush();
 		$lamdaemonOk = false;
-		$errorMessage = "";
-		$shell = ssh2_exec($handle, "sudo " . $_SESSION['config']->scriptPath);
+		$shell = ssh2_exec($handle, "sudo " . $_SESSION['config']->get_scriptPath());
 		$stderr = ssh2_fetch_stream($shell, SSH2_STREAM_STDERR);
 		fwrite($shell, $command);
 		$return = array();
@@ -96,12 +165,12 @@ function lamTestLamdaemon($command, $stopTest, $handle, $testText) {
 			$lamdaemonOk = true;
 		}
 		if ($lamdaemonOk) {
-			echo "<td bgcolor=\"green\">" . _("Ok") . "</td>";
-			echo "<td bgcolor=\"green\">" . _("Lamdaemon successfully run.") . "</td>";
+			echo "<td>" . $okImage . "</td>";
+			echo "<td>" . _("Lamdaemon successfully run.") . "</td>";
 		}
 		else {
-			echo "<td bgcolor=\"red\">" . _("Error") . "&nbsp;&nbsp;</td>\n";
-			echo "<td bgcolor=\"red\">\n";
+			echo "<td>" . $failImage . "&nbsp;&nbsp;</td>\n";
+			echo "<td>\n";
 			for ($i = 0; $i < sizeof($return); $i++) {
 				call_user_func_array('StatusMessage', split(",", $return[$i]));
 			}
@@ -114,38 +183,38 @@ function lamTestLamdaemon($command, $stopTest, $handle, $testText) {
 	return $stopTest;
 }
 
-$servers = explode(";", $_SESSION['config']->get_scriptServers());
-for ($i = 0; $i < sizeof($servers); $i++) {
-	$servers[$i] = explode(":", $servers[$i]);
-	$serverName = $servers[$i][0];
-	$title = $serverName;
-	$serverDisplayName = $servers[$i][0];
-	if (isset($servers[$i][1])) {
-		$serverDisplayName = $servers[$i][1];
-		$title = $serverDisplayName . " (" . $serverName . ")";
-	}
-
+/**
+ * Runs all tests for a given server.
+ *
+ * @param String $serverName server ID
+ * @param String $serverTitle server name
+ * @param boolean $testQuota true, if Quotas should be checked
+ */
+function lamRunLamdaemonTestSuite($serverName, $serverTitle, $testQuota) {
+	$okImage = "<img src=\"../../graphics/pass.png\" alt=\"\">\n";
+	$failImage = "<img src=\"../../graphics/fail.png\" alt=\"\">\n";
+	
 	echo "<table class=\"userlist\" rules=\"none\" width=\"750\">\n";
 
 	flush();
 	$stopTest = false;
 
-	echo "<tr class=\"userlist\">\n<td colspan=\"3\" align=\"center\"><b>$title</b>\n</td>\n</tr>";
+	echo "<tr class=\"userlist\">\n<td colspan=\"3\" align=\"center\"><b>$serverTitle</b>\n</td>\n</tr>";
 
 	// check script server and path
-	echo "<tr class=\"userlist\">\n<td>" . _("Lamdaemon server and path") . "&nbsp;&nbsp;</td>\n";
+	echo "<tr class=\"userlist\">\n<td nowrap>" . _("Lamdaemon server and path") . "&nbsp;&nbsp;</td>\n";
 	if (!isset($serverName) || (strlen($serverName) < 3)) {
-		echo "<td>" . _("Error") . "</td>\n";
-		echo "<td bgcolor=\"red\">" . _("No lamdaemon server set, please update your LAM configuration settings.") . "</td>";
+		echo "<td>" . $failImage . "</td>\n";
+		echo "<td>" . _("No lamdaemon server set, please update your LAM configuration settings.") . "</td>";
 	}
-	elseif (!isset($_SESSION['config']->scriptPath) || (strlen($_SESSION['config']->scriptPath) < 10)) {
-		echo "<td bgcolor=\"red\">" . _("Error") . "&nbsp;&nbsp;</td>\n";
-		echo "<td bgcolor=\"red\">" . _("No lamdaemon path set, please update your LAM configuration settings.") . "</td>";
+	elseif (($_SESSION['config']->get_scriptPath() == null) || (strlen($_SESSION['config']->get_scriptPath()) < 10)) {
+		echo "<td>" . $failImage . "&nbsp;&nbsp;</td>\n";
+		echo "<td>" . _("No lamdaemon path set, please update your LAM configuration settings.") . "</td>";
 		$stopTest = true;
 	}
 	else {
-		echo "<td bgcolor=\"green\">" . _("Ok") . "&nbsp;&nbsp;</td>\n";
-		echo "<td bgcolor=\"green\">" . sprintf(_("Using %s as lamdaemon remote server."), $serverName) . "</td>";
+		echo "<td>" . $okImage . "&nbsp;&nbsp;</td>\n";
+		echo "<td>" . sprintf(_("Using %s as lamdaemon remote server."), $serverName) . "</td>";
 	}
 	echo "</tr>\n";
 
@@ -153,7 +222,7 @@ for ($i = 0; $i < sizeof($servers); $i++) {
 
 	// check Unix account of LAM admin
 	if (!$stopTest) {
-		echo "<tr class=\"userlist\">\n<td>" . _("Unix account") . "&nbsp;&nbsp;</td>\n";
+		echo "<tr class=\"userlist\">\n<td nowrap>" . _("Unix account") . "&nbsp;&nbsp;</td>\n";
 		$credentials = $_SESSION['ldap']->decrypt_login();
 		$unixOk = false;
 		$sr = @ldap_read($_SESSION['ldap']->server(), $credentials[0], "objectClass=posixAccount", array('uid'));
@@ -165,12 +234,12 @@ for ($i = 0; $i < sizeof($servers); $i++) {
 			}
 		}
 		if ($unixOk) {
-			echo "<td bgcolor=\"green\">" . _("Ok") . "</td>\n";
-			echo "<td bgcolor=\"green\">" . sprintf(_("Using %s to connect to remote server."), $userName) . "</td>";
+			echo "<td>" . $okImage . "</td>\n";
+			echo "<td>" . sprintf(_("Using %s to connect to remote server."), $userName) . "</td>";
 		}
 		else {
-			echo "<td bgcolor=\"red\">" . _("Error") . "&nbsp;&nbsp;</td>\n";
-			echo "<td bgcolor=\"red\">" . sprintf(_("Your LAM admin user (%s) must be a valid Unix account to work with lamdaemon!"), $credentials[0]) . "</td>";
+			echo "<td>" . $failImage . "&nbsp;&nbsp;</td>\n";
+			echo "<td>" . sprintf(_("Your LAM admin user (%s) must be a valid Unix account to work with lamdaemon!"), $credentials[0]) . "</td>";
 			$stopTest = true;
 		}
 		echo "</tr>\n";
@@ -180,14 +249,14 @@ for ($i = 0; $i < sizeof($servers); $i++) {
 
 	// check SSH2 function
 	if (!$stopTest) {
-		echo "<tr class=\"userlist\">\n<td>" . _("SSH2 module") . "&nbsp;&nbsp;</td>\n";
+		echo "<tr class=\"userlist\">\n<td nowrap>" . _("SSH2 module") . "&nbsp;&nbsp;</td>\n";
 		if (function_exists("ssh2_connect")) {
-			echo "<td bgcolor=\"green\">" . _("Ok") . "</td>";
-			echo "<td bgcolor=\"green\">" . _("SSH2 module is installed.") . "</td>";
+			echo "<td>" . $okImage . "</td>";
+			echo "<td>" . _("SSH2 module is installed.") . "</td>";
 		}
 		else {
-			echo "<td bgcolor=\"red\">" . _("Error") . "&nbsp;&nbsp;</td>\n";
-			echo "<td bgcolor=\"red\">" . _("Please install the SSH2 module for PHP and activate it in your php.ini!") . "</td>";
+			echo "<td>" . $failImage . "&nbsp;&nbsp;</td>\n";
+			echo "<td>" . _("Please install the SSH2 module for PHP and activate it in your php.ini!") . "</td>";
 			$stopTest = true;
 		}
 		echo "</tr>\n";
@@ -197,7 +266,7 @@ for ($i = 0; $i < sizeof($servers); $i++) {
 
 	// check SSH login
 	if (!$stopTest) {
-		echo "<tr class=\"userlist\">\n<td>" . _("SSH connection") . "&nbsp;&nbsp;</td>\n";
+		echo "<tr class=\"userlist\">\n<td nowrap>" . _("SSH connection") . "&nbsp;&nbsp;</td>\n";
 		flush();
 		$sshOk = false;
 		$handle = @ssh2_connect($serverName);
@@ -207,12 +276,12 @@ for ($i = 0; $i < sizeof($servers); $i++) {
 			}
 		}
 		if ($sshOk) {
-			echo "<td bgcolor=\"green\">" . _("Ok") . "</td>";
-			echo "<td bgcolor=\"green\">" . _("SSH connection could be established.") . "</td>";
+			echo "<td>" . $okImage . "</td>";
+			echo "<td>" . _("SSH connection could be established.") . "</td>";
 		}
 		else {
-			echo "<td bgcolor=\"red\">" . _("Error") . "&nbsp;&nbsp;</td>\n";
-			echo "<td bgcolor=\"red\">" . _("Unable to connect to remote server!") . "</td>";
+			echo "<td>" . $failImage . "&nbsp;&nbsp;</td>\n";
+			echo "<td>" . _("Unable to connect to remote server!") . "</td>";
 			$stopTest = true;
 		}
 		echo "</tr>\n";
@@ -221,17 +290,14 @@ for ($i = 0; $i < sizeof($servers); $i++) {
 	flush();
 
 	$stopTest = lamTestLamdaemon("+ test basic\n", $stopTest, $handle, _("Execute lamdaemon"));
-	$stopTest = lamTestLamdaemon("+ test quota\n", $stopTest, $handle, _("Lamdaemon: Quota module installed"));
-	$stopTest = lamTestLamdaemon("+ quota get user\n", $stopTest, $handle, _("Lamdaemon: read quotas"));
+	if ($testQuota) {
+		$stopTest = lamTestLamdaemon("+ test quota\n", $stopTest, $handle, _("Lamdaemon: Quota module installed"));
+		$stopTest = lamTestLamdaemon("+ quota get user\n", $stopTest, $handle, _("Lamdaemon: read quotas"));
+	}
 
-	echo "<br />";
+	echo "</table><br>\n";
 	
-	echo "</table>\n";
+	echo "<h2>" . _("Lamdaemon test finished.") . "</h2>\n";
 }
 
-echo "<h2>" . _("Lamdaemon test finished.") . "</h2>\n";
-
-echo "</body>\n";
-echo "</html>\n";
-
 ?>
