@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: download_binary_attr.php,v 1.2 2006/03/26 17:51:25 gruberroland Exp $
+$Id: download_binary_attr.php,v 1.3 2007/07/08 10:49:07 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   
@@ -60,7 +60,7 @@ $attr = $_GET['attr'];
 // if there are multiple values in this attribute, which one do you want to see?
 $value_num = isset( $_GET['value_num'] ) ? $_GET['value_num'] : 0;
 
-$ds = $_SESSION['ldap']->server;
+$ds = $_SESSION['ldap']->server();
 
 $search = @ldap_read( $ds, $dn, "(objectClass=*)", array($attr));
 if( ! $search ) {
