@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: tree.php,v 1.2 2006/03/26 17:51:25 gruberroland Exp $
+$Id: tree.php,v 1.3 2008/01/01 15:00:46 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   
@@ -174,6 +174,9 @@ function draw_tree_html( $dn, $level = 0 )
 
 function draw_create_link( $rdn, $level, $encoded_dn )
 {
+	if (!checkIfWriteAccessIsAllowed()) {
+		return;
+	}
     // print the "Create New object" link.
     $create_html = "";
     $create_href = "create_form.php?container=$encoded_dn";
